Rindle docs and package mapSkip to main content

DiffSink

Trait DiffSink 

pub trait DiffSink {
    // Required methods
    fn only_this(&mut self, row: &OwnedRow);
    fn only_other(&mut self, row: &OwnedRow);
    fn edit(&mut self, this: &OwnedRow, other: &OwnedRow);
}
Sink for BTree::diff_visit: one callback per difference, emitted in descending sort order. “this” is self; “other” is the argument tree.

Required Methods

fn only_this(&mut self, row: &OwnedRow)

A row present in self but not in other.

fn only_other(&mut self, row: &OwnedRow)

A row present in other but not in self.

fn edit(&mut self, this: &OwnedRow, other: &OwnedRow)

Equal sort-key but differing content: this (in self) → other.

Implementors