Rindle docs and package mapSkip to main content

schema_fp

Function schema_fp 

pub fn schema_fp(ws: &WireSchema) -> SchemaFp
Fingerprint a resolved WireSchema. The PK and sort are hashed by column name (resolved through columns), so the fingerprint is a semantic identity independent of any internal ColId numbering (5.5).