Function unsafe_int_in_cells
pub fn unsafe_int_in_cells(row: &[OwnedValue]) -> Option<i64>Expand description
The first out-of-safe-range Int in a positional cell slice, if any.
pub fn unsafe_int_in_cells(row: &[OwnedValue]) -> Option<i64>The first out-of-safe-range Int in a positional cell slice, if any.