pub struct FlatChange {
pub path: Vec<PathSeg>,
pub op: FlatOp,
}Expand description
One flat change: the root→leaf parent path, then the op applied at the reached
level. An empty path means the op applies at the top level.
Fields
path: Vec<PathSeg>op: FlatOpTrait Implementations
Sourceimpl Clone for FlatChange
impl Clone for FlatChange
Sourcefn clone(&self) -> FlatChange
fn clone(&self) -> FlatChange
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FlatChange
impl Debug for FlatChange
Sourceimpl<'de> Deserialize<'de> for FlatChange
impl<'de> Deserialize<'de> for FlatChange
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more