Function upsert_lmid
pub fn upsert_lmid(
tx: &Connection,
client_id: &str,
mid: u64,
) -> Result<(), BookkeepingError>Expand description
Upsert the durable last mutation id inside the caller’s open transaction.
pub fn upsert_lmid(
tx: &Connection,
client_id: &str,
mid: u64,
) -> Result<(), BookkeepingError>Upsert the durable last mutation id inside the caller’s open transaction.