Function read_producer_seq
pub fn read_producer_seq(
tx: &Connection,
producer: &str,
) -> Result<u64, BookkeepingError>Expand description
Read the durable last sequence a producer wrote, or zero when the producer is new.
pub fn read_producer_seq(
tx: &Connection,
producer: &str,
) -> Result<u64, BookkeepingError>Read the durable last sequence a producer wrote, or zero when the producer is new.