pub struct FamilyExtraction {
pub key: FamilyKey,
pub template: FamilyTemplate,
pub binding: Vec<CanonVal>,
}Expand description
A parameterized query family’s identity and template (design 310 3), re-exported from
rindle-wire so a daemon groups subscriptions with the same types the engine binds on.
The result of a successful extraction: the family the query belongs to, the template
its pipeline compiles from, and the binding this query is.
Fields
key: FamilyKeytemplate: FamilyTemplatebinding: Vec<CanonVal>Trait Implementations
Sourceimpl Clone for FamilyExtraction
impl Clone for FamilyExtraction
Sourcefn clone(&self) -> FamilyExtraction
fn clone(&self) -> FamilyExtraction
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for FamilyExtraction
impl RefUnwindSafe for FamilyExtraction
impl Send for FamilyExtraction
impl Sync for FamilyExtraction
impl Unpin for FamilyExtraction
impl UnsafeUnpin for FamilyExtraction
impl UnwindSafe for FamilyExtraction